@@ -6,8 +6,8 @@ from F import DICT
 from F.CLASS import Flass
 from F.TYPE.Dict import fict
 
-# redis-cli -h 192.168.1.229 -p 6379 -a <password>
-# host='192.168.1.229'
+# redis-cli -h 192.168.1.xxx -p 6379 -a <password>
+# host='192.168.1.xxx'
 # port=6379
 # db=0
 # -> pubsub {'type': 'message', 'pattern': None, 'channel': b'channel-1', 'data': b'this is a dykw message!'}
@@ -56,6 +56,9 @@ class Redis(Flass):
             return self.get_fict(key)
         return self.client.get(key)
 
+    def get_config(self, key):
+        return self.get_fict(CONFIG_KEY(key))
+
     def get_fict(self, key):
         result = self.client.get(key)
         result = self.parse_str_to_dict(result)
@@ -106,10 +109,10 @@ class Redis(Flass):
 
 if __name__ == '__main__':
     r = Redis(ip="192.168.1.229")
-    CONFIG_MODEL["ip"] = "192.168.1.229"
-    CONFIG_MODEL["host"] = "192.168.1.229"
+    CONFIG_MODEL["ip"] = "192.168.1.xxx"
+    CONFIG_MODEL["host"] = "192.168.1.xxx"
     CONFIG_MODEL["port"] = "6379"
     CONFIG_MODEL["db"] = "0"
-    CONFIG_MODEL["username"] = "chazzcoin"
-    CONFIG_MODEL["password"] = "wonderwall"
+    CONFIG_MODEL["username"] = ""
+    CONFIG_MODEL["password"] = ""
     r.set(CONFIG_KEY("redis"), CONFIG_MODEL)
\ No newline at end of file
